| simLong | R Documentation |
Generate synthetic longitudinal data for continuous or binary responses.
simLong(
n = 100,
n.test = 0,
n.time = 5,
rho = 0.8,
cor.type = c("cor.comp.sym", "cor.ar1", "cor.symm", "iid"),
model = c(0, 1, 2, 3),
family = c("continuous", "binary"),
phi = 1,
q = 0,
...
)
n |
Number of training subjects. |
n.test |
Number of additional test subjects to generate. |
n.time |
Controls the number and scale of repeated observation times. |
rho |
Working correlation parameter used by the data generator. |
cor.type |
Correlation structure used for the repeated errors. |
model |
Signal-generating model. Choose one of |
family |
Response family. Choose |
phi |
Error-scale parameter. |
q |
Number of additional noise covariates to append to the baseline feature set. |
... |
Currently ignored. |
A list with components:
A list containing features, time,
id, and y.
The full long-format simulated data frame.
Indices identifying the training portion of
data.
A character string describing the true signal model.
Hemant Ishwaran, Amol Pande, and Udaya B. Kogalur
boostmtree
set.seed(5)
sim.obj <- simLong(n = 10, n.time = 4, family = "continuous")
str(sim.obj$data.list, max.level = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.